@@ -177,7 +177,7 @@ def do_get_templ(args):
     namelist = downloader.extract_zip_to(to, args.saveto)
     os.remove(to)
 
-    if args.raw:
+    if not args.raw:
         print("Replace project variable")
         variable_template = get_variable_template()
         process_code_template.process_code_template(args.saveto, namelist, variable_template)
